<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Duplicate</name>
    <message>
        <location filename="../DuplicateInit.js" line="+2"/>
        <source>&amp;Duplicate</source>
        <translation>&amp;Duplikovať</translation>
    </message>
    <message>
        <source>1 entity duplicated</source>
        <translation type="vanished">1 duplicitný prvok</translation>
    </message>
    <message>
        <source>%1 entities duplicated</source>
        <translation type="vanished">%1 duplicitné (-ých) prvky (-ov)</translation>
    </message>
    <message numerus="yes">
        <location filename="../Duplicate.js" line="+54"/>
        <source>%n entity/ies duplicated</source>
        <translation>
            <numerusform>%n duplicitný (-é) prvok (-y)</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
</TS>
